@@ -69,11 +69,7 @@ void initconstants(void)
 	DEC_CONST(RLEACCEL);
 	DEC_CONST(SRCALPHA);
 	DEC_CONST(PREALLOC);
-#if SDL_VERSIONNUM(1, 1, 8) <= SDL_VERSIONNUM(SDL_MAJOR_VERSION, SDL_MINOR_VERSION, SDL_PATCHLEVEL) 
 	DEC_CONST(NOFRAME);
-#else
-	PyModule_AddIntConstant(module, "NOFRAME", 0);
-#endif
 
 	DEC_CONST(GL_RED_SIZE);
 	DEC_CONST(GL_GREEN_SIZE);
@@ -87,6 +83,18 @@ void initconstants(void)
 	DEC_CONST(GL_ACCUM_GREEN_SIZE);
 	DEC_CONST(GL_ACCUM_BLUE_SIZE);
 	DEC_CONST(GL_ACCUM_ALPHA_SIZE);
+#if SDL_VERSION_ATLEAST(1, 2, 5)
+	DEC_CONST(GL_STEREO);
+#else
+	PyModule_AddIntConstant(module, "GL_STEREO", -1);
+#endif
+#if SDL_VERSION_ATLEAST(1, 2, 6)
+	DEC_CONST(GL_MULTISAMPLEBUFFERS);
+	DEC_CONST(GL_MULTISAMPLESAMPLES);
+#else
+	PyModule_AddIntConstant(module, "GL_MULTISAMPLEBUFFERS", -1);
+	PyModule_AddIntConstant(module, "GL_MULTISAMPLESAMPLES", -1);
+#endif
 
 	DEC_CONSTN(AUDIO_U8);
 	DEC_CONSTN(AUDIO_S8);
@@ -98,7 +106,7 @@ void initconstants(void)
 	DEC_CONSTN(AUDIO_S16);
 	DEC_CONSTN(AUDIO_U16SYS);
 	DEC_CONSTN(AUDIO_S16SYS);
-	
+
 	DEC_CONST(NOEVENT);
 	DEC_CONST(ACTIVEEVENT);
 	DEC_CONST(KEYDOWN);
@@ -112,7 +120,7 @@ void initconstants(void)
 	DEC_CONST(JOYBUTTONDOWN);
 	DEC_CONST(JOYBUTTONUP);
 	DEC_CONST(VIDEORESIZE);
-#if SDL_VERSIONNUM(1, 2, 2) <= SDL_VERSIONNUM(SDL_MAJOR_VERSION, SDL_MINOR_VERSION, SDL_PATCHLEVEL) 
+#if SDL_VERSIONNUM(1, 2, 2) <= SDL_VERSIONNUM(SDL_MAJOR_VERSION, SDL_MINOR_VERSION, SDL_PATCHLEVEL)
 	DEC_CONST(VIDEOEXPOSE);
 #else
 	PyModule_AddIntConstant(module, "VIDEOEXPOSE", 0);
