@@ -112,7 +112,7 @@ static PyObject* aaline(PyObject* self, PyObject* arg)
 
 	/*compute return rect*/
 	if(!anydraw)
-		return PyRect_New4((short)(startx), (short)(starty), 0, 0);
+		return PyRect_New4(startx, starty, 0, 0);
 	if(pts[0] < pts[2])
 	{
 		left = (int)(pts[0]);
@@ -133,7 +133,7 @@ static PyObject* aaline(PyObject* self, PyObject* arg)
 		top = (int)(pts[3]);
 		bottom = (int)(pts[1]);
 	}
-	return PyRect_New4((short)left, (short)top, (short)(right-left+2), (short)(bottom-top+2));
+	return PyRect_New4(left, top, right-left+2, bottom-top+2);
 }
 
     /*DOC*/ static char doc_line[] =
@@ -153,7 +153,7 @@ static PyObject* line(PyObject* self, PyObject* arg)
 {
 	PyObject *surfobj, *colorobj, *start, *end;
 	SDL_Surface* surf;
-	short startx, starty, endx, endy;
+	int startx, starty, endx, endy;
 	int top, left, bottom, right;
 	int width = 1;
 	int pts[4];
@@ -176,9 +176,9 @@ static PyObject* line(PyObject* self, PyObject* arg)
 	else
 		return RAISE(PyExc_TypeError, "invalid color argument");
 
-	if(!TwoShortsFromObj(start, &startx, &starty))
+	if(!TwoIntsFromObj(start, &startx, &starty))
 		return RAISE(PyExc_TypeError, "Invalid start position argument");
-	if(!TwoShortsFromObj(end, &endx, &endy))
+	if(!TwoIntsFromObj(end, &endx, &endy))
 		return RAISE(PyExc_TypeError, "Invalid end position argument");
 
 	if(width < 1)
@@ -217,7 +217,7 @@ static PyObject* line(PyObject* self, PyObject* arg)
 		top = pts[3];
 		bottom = pts[1];
 	}
-	return PyRect_New4((short)left, (short)top, (short)(right-left+1), (short)(bottom-top+1));
+	return PyRect_New4(left, top, right-left+1, bottom-top+1);
 }
 
 
@@ -258,7 +258,7 @@ static PyObject* aalines(PyObject* self, PyObject* arg)
 		&points, &blend))
 		return NULL;
 	surf = PySurface_AsSurface(surfobj);
-	
+
 	if(surf->format->BytesPerPixel !=3 && surf->format->BytesPerPixel != 4)
 		return RAISE(PyExc_ValueError, "unsupported bit depth for aaline draw (supports 32 & 24 bit)");
 
@@ -325,7 +325,7 @@ static PyObject* aalines(PyObject* self, PyObject* arg)
 	if(!PySurface_Unlock(surfobj)) return NULL;
 
 	/*compute return rect*/
-	return PyRect_New4((short)left, (short)top, (short)(right-left+2), (short)(bottom-top+2));
+	return PyRect_New4(left, top, right-left+2, bottom-top+2);
 }
 
     /*DOC*/ static char doc_lines[] =
@@ -351,7 +351,7 @@ static PyObject* lines(PyObject* self, PyObject* arg)
 {
 	PyObject *surfobj, *colorobj, *closedobj, *points, *item;
 	SDL_Surface* surf;
-	short x, y;
+	int x, y;
 	int top, left, bottom, right;
 	int pts[4], width=1;
 	Uint8 rgba[4];
@@ -384,7 +384,7 @@ static PyObject* lines(PyObject* self, PyObject* arg)
 		return RAISE(PyExc_ValueError, "points argument must contain more than 1 points");
 
 	item = PySequence_GetItem(points, 0);
-	result = TwoShortsFromObj(item, &x, &y);
+	result = TwoIntsFromObj(item, &x, &y);
 	Py_DECREF(item);
 	if(!result) return RAISE(PyExc_TypeError, "points must be number pairs");
 
@@ -392,7 +392,7 @@ static PyObject* lines(PyObject* self, PyObject* arg)
 	starty = pts[1] = top = bottom = y;
 
 	if(width < 1)
-		return PyRect_New4((short)left, (short)top, 0, 0);
+		return PyRect_New4(left, top, 0, 0);
 
 	if(!PySurface_Lock(surfobj)) return NULL;
 
@@ -400,7 +400,7 @@ static PyObject* lines(PyObject* self, PyObject* arg)
 	for(loop = 1; loop < length; ++loop)
 	{
 		item = PySequence_GetItem(points, loop);
-		result = TwoShortsFromObj(item, &x, &y);
+		result = TwoIntsFromObj(item, &x, &y);
 		Py_DECREF(item);
 		if(!result) continue; /*note, we silently skip over bad points :[ */
 		++drawn;
@@ -419,7 +419,7 @@ static PyObject* lines(PyObject* self, PyObject* arg)
 	if(closed && drawn > 2)
 	{
 		item = PySequence_GetItem(points, 0);
-		result = TwoShortsFromObj(item, &x, &y);
+		result = TwoIntsFromObj(item, &x, &y);
 		Py_DECREF(item);
 		if(result)
 		{
@@ -435,7 +435,7 @@ static PyObject* lines(PyObject* self, PyObject* arg)
 	if(!PySurface_Unlock(surfobj)) return NULL;
 
 	/*compute return rect*/
-	return PyRect_New4((short)left, (short)top, (short)(right-left+1), (short)(bottom-top+1));
+	return PyRect_New4(left, top, right-left+1, bottom-top+1);
 }
 
 
@@ -464,7 +464,7 @@ static PyObject* arc(PyObject* self, PyObject* arg)
 	double angle_start, angle_stop;
 
 	/*get all the arguments*/
-	if(!PyArg_ParseTuple(arg, "O!OOdd|i", &PySurface_Type, &surfobj, &colorobj, &rectobj, 
+	if(!PyArg_ParseTuple(arg, "O!OOdd|i", &PySurface_Type, &surfobj, &colorobj, &rectobj,
 			                      &angle_start, &angle_stop, &width))
 		return NULL;
 	rect = GameRect_FromObject(rectobj, &temp);
@@ -505,7 +505,7 @@ static PyObject* arc(PyObject* self, PyObject* arg)
 	t = max(rect->y, surf->clip_rect.y);
 	r = min(rect->x + rect->w, surf->clip_rect.x + surf->clip_rect.w);
 	b = min(rect->y + rect->h, surf->clip_rect.y + surf->clip_rect.h);
-	return PyRect_New4((short)l, (short)t, (short)max(r-l, 0), (short)max(b-t, 0));
+	return PyRect_New4(l, t, max(r-l, 0), max(b-t, 0));
 }
 
 
@@ -577,7 +577,7 @@ static PyObject* ellipse(PyObject* self, PyObject* arg)
 	t = max(rect->y, surf->clip_rect.y);
 	r = min(rect->x + rect->w, surf->clip_rect.x + surf->clip_rect.w);
 	b = min(rect->y + rect->h, surf->clip_rect.y + surf->clip_rect.h);
-	return PyRect_New4((short)l, (short)t, (short)max(r-l, 0), (short)max(b-t, 0));
+	return PyRect_New4(l, t, max(r-l, 0), max(b-t, 0));
 }
 
 
@@ -642,7 +642,7 @@ static PyObject* circle(PyObject* self, PyObject* arg)
 	t = max(posy - radius, surf->clip_rect.y);
 	r = min(posx + radius, surf->clip_rect.x + surf->clip_rect.w);
 	b = min(posy + radius, surf->clip_rect.y + surf->clip_rect.h);
-	return PyRect_New4((short)l, (short)t, (short)max(r-l, 0), (short)max(b-t, 0));
+	return PyRect_New4(l, t, max(r-l, 0), max(b-t, 0));
 }
 
 
@@ -670,13 +670,13 @@ static PyObject* polygon(PyObject* self, PyObject* arg)
 	Uint32 color;
 	int width=0, length, loop, numpoints;
 	int *xlist, *ylist;
-	short x, y, top, left, bottom, right, result;
+	int x, y, top, left, bottom, right, result;
 
 	/*get all the arguments*/
 	if(!PyArg_ParseTuple(arg, "O!OO|i", &PySurface_Type, &surfobj, &colorobj, &points, &width))
 		return NULL;
 
-	
+
 	if(width)
 	{
 		PyObject *args, *ret;
@@ -708,7 +708,7 @@ static PyObject* polygon(PyObject* self, PyObject* arg)
 
 
 	item = PySequence_GetItem(points, 0);
-	result = TwoShortsFromObj(item, &x, &y);
+	result = TwoIntsFromObj(item, &x, &y);
 	Py_DECREF(item);
 	if(!result) return RAISE(PyExc_TypeError, "points must be number pairs");
 	left = right = x;
@@ -721,7 +721,7 @@ static PyObject* polygon(PyObject* self, PyObject* arg)
 	for(loop = 0; loop < length; ++loop)
 	{
 		item = PySequence_GetItem(points, loop);
-		result = TwoShortsFromObj(item, &x, &y);
+		result = TwoIntsFromObj(item, &x, &y);
 		Py_DECREF(item);
 		if(!result) continue; /*note, we silently skip over bad points :[ */
 		xlist[numpoints] = x;
@@ -749,7 +749,7 @@ static PyObject* polygon(PyObject* self, PyObject* arg)
 	top = max(top, surf->clip_rect.y);
 	right = min(right, surf->clip_rect.x + surf->clip_rect.w);
 	bottom = min(bottom, surf->clip_rect.y + surf->clip_rect.h);
-	return PyRect_New4(left, top, (short)(right-left+1), (short)(bottom-top+1));
+	return PyRect_New4(left, top, right-left+1, bottom-top+1);
 }
 
 
@@ -943,28 +943,28 @@ static int clipaaline(float* pts, int left, int top, int right, int bottom)
 				swaptmp = y2; y2 = y1; y1 = swaptmp;
 				intswaptmp = code2; code2 = code1; code1 = intswaptmp;
 			}
-			if(x2 != x1)	  
+			if(x2 != x1)
 				m = (y2 - y1) / (x2 - x1);
 			else
 				m = 1.0f;
 			if(code1 & LEFT_EDGE) {
 				y1 += ((float)left - x1) * m;
-				x1 = (float)left; 
-			} 
+				x1 = (float)left;
+			}
 			else if(code1 & RIGHT_EDGE) {
 				y1 += ((float)right - x1) * m;
-				x1 = (float)right; 
-			} 
+				x1 = (float)right;
+			}
 			else if(code1 & BOTTOM_EDGE) {
 				if(x2 != x1)
 					x1 += ((float)bottom - y1) / m;
 				y1 = (float)bottom;
-			} 
+			}
 			else if(code1 & TOP_EDGE) {
 				if(x2 != x1)
 					x1 += ((float)top - y1) / m;
 				y1 = (float)top;
-			} 
+			}
 		}
 	}
 	if(draw) {
@@ -1001,28 +1001,28 @@ static int clipline(int* pts, int left, int top, int right, int bottom)
 				swaptmp = y2; y2 = y1; y1 = swaptmp;
 				swaptmp = code2; code2 = code1; code1 = swaptmp;
 			}
-			if(x2 != x1)	  
+			if(x2 != x1)
 				m = (y2 - y1) / (float)(x2 - x1);
 			else
 				m = 1.0f;
 			if(code1 & LEFT_EDGE) {
 				y1 += (int)((left - x1) * m);
-				x1 = left; 
-			} 
+				x1 = left;
+			}
 			else if(code1 & RIGHT_EDGE) {
 				y1 += (int)((right - x1) * m);
-				x1 = right; 
-			} 
+				x1 = right;
+			}
 			else if(code1 & BOTTOM_EDGE) {
 				if(x2 != x1)
 					x1 += (int)((bottom - y1) / m);
 				y1 = bottom;
-			} 
+			}
 			else if(code1 & TOP_EDGE) {
 				if(x2 != x1)
 					x1 += (int)((top - y1) / m);
 				y1 = top;
-			} 
+			}
 		}
 	}
 	if(draw) {
@@ -1072,7 +1072,7 @@ static int set_at(SDL_Surface* surf, int x, int y, Uint32 color)
 #define DRAWPIX32(pixel,colorptr,br,blend) \
 	if(SDL_BYTEORDER == SDL_BIG_ENDIAN) color <<= 8; \
 	if(blend) { \
-		short x; \
+		int x; \
 		x = colorptr[0]*br+pixel[0]; \
 		pixel[0]= (x>254) ? 255: x; \
 		x = colorptr[1]*br+pixel[1]; \
@@ -1131,7 +1131,7 @@ static void drawaaline(SDL_Surface* surf, Uint32 color, float x1, float y1, floa
 		brightness2 =    FRAC(yend) * xgap;
 		pixel = pm + pixx * ix2 + pixy * iy2;
 		DRAWPIX32(pixel, colorptr, brightness1, blend)
-		pixel += pixy; 
+		pixel += pixy;
 		DRAWPIX32(pixel, colorptr, brightness2, blend)
 		for(x=ix1+1; x<ix2; ++x) {
 			brightness1=INVFRAC(yf);
@@ -1163,7 +1163,7 @@ static void drawaaline(SDL_Surface* surf, Uint32 color, float x1, float y1, floa
 		DRAWPIX32(pixel, colorptr, brightness1, blend)
 		pixel += pixx;
 		DRAWPIX32(pixel, colorptr, brightness2, blend)
-		yend = trunc(y2)+0.5; 
+		yend = trunc(y2)+0.5;
 		xend = x2+grad*(yend-y2);
 		ygap = FRAC(y2);
 		iy2 = (int)yend;
@@ -1172,7 +1172,7 @@ static void drawaaline(SDL_Surface* surf, Uint32 color, float x1, float y1, floa
 		brightness2 =    FRAC(xend) * ygap;
 		pixel = pm + pixx * ix2 + pixy * iy2;
 		DRAWPIX32(pixel, colorptr, brightness1, blend)
-		pixel += pixx; 
+		pixel += pixx;
 		DRAWPIX32(pixel, colorptr, brightness2, blend)
 		for(y=iy1+1; y<iy2; ++y) {
 			brightness1=INVFRAC(xf);
@@ -1252,7 +1252,11 @@ static void drawhorzline(SDL_Surface* surf, Uint32 color, int x1, int y1, int x2
 	Uint8 *pixel, *end;
 	Uint8 *colorptr;
 
-	if(x1 == x2) return;
+	if(x1 == x2)
+        {
+            set_at(surf, x1, y1, color);
+            return;
+        }
 
 	pixel = ((Uint8*)surf->pixels) + surf->pitch * y1;
 	if(x1 < x2)
@@ -1319,7 +1323,11 @@ static void drawvertline(SDL_Surface* surf, Uint32 color, int x1, int y1, int y2
        Uint8   *colorptr;
        Uint32  pitch = surf->pitch;
 
-       if(y1 == y2) return;
+       if(y1 == y2)
+       {
+           set_at(surf, x1, y1, color);
+           return;
+       }
 
        pixel = ((Uint8*)surf->pixels) + x1 * surf->format->BytesPerPixel;
        if(y1 < y2)
@@ -1422,7 +1430,7 @@ static void draw_ellipse(SDL_Surface *dst, int x, int y, int rx, int ry, Uint32
 	int xmi, xpi, ymj, ypj;
 	int xmj, xpj, ymi, ypi;
 	int xmk, xpk, ymh, yph;
-	
+
 	if (rx==0 && ry==0) {  /* Special case - draw a single pixel */
 		set_at( dst, x, y, color);
 		return;
@@ -1546,20 +1554,20 @@ static void draw_fillellipse(SDL_Surface *dst, int x, int y, int rx, int ry, Uin
 
 	/* Init vars */
 	oh = oi = oj = ok = 0xFFFF;
-	
+
 	/* Draw */
 	if (rx >= ry) {
 		ix = 0;
 		iy = rx * 64;
-		
+
 		do {
-			h = (ix + 4/*32*/) >> 6;
-			i = (iy + 4/*32*/) >> 6;
+			h = (ix + 8) >> 6;
+			i = (iy + 8) >> 6;
 			j = (h * ry) / rx;
 			k = (i * ry) / rx;
-			if ((ok!=k) && (oj!=k)) {
-				drawhorzlineclip(dst, color, x-h, y+k, x+h-1);
+			if ((ok!=k) && (oj!=k) && (k<ry)) {
 				drawhorzlineclip(dst, color, x-h, y-k-1, x+h-1);
+				drawhorzlineclip(dst, color, x-h, y+k, x+h-1);
 				ok=k;
 			}
 			if ((oj!=j) && (ok!=j) && (k!=j))  {
@@ -1569,19 +1577,19 @@ static void draw_fillellipse(SDL_Surface *dst, int x, int y, int rx, int ry, Uin
 			}
 			ix = ix + iy / rx;
 			iy = iy - ix / rx;
-			
+
 		} while (i > h);
 	} else {
 		ix = 0;
 		iy = ry * 64;
-		
+
 		do {
-			h = (ix + 32) >> 6;
-			i = (iy + 32) >> 6;
+			h = (ix + 8) >> 6;
+			i = (iy + 8) >> 6;
 			j = (h * rx) / ry;
 			k = (i * rx) / ry;
-			
-			if ((oi!=i) && (oh!=i)) {
+
+			if ((oi!=i) && (oh!=i) && (i<ry)) {
 				drawhorzlineclip(dst, color, x-j, y+i, x+j-1);
 				drawhorzlineclip(dst, color, x-j, y-i-1, x+j-1);
 				oi=i;
@@ -1591,10 +1599,10 @@ static void draw_fillellipse(SDL_Surface *dst, int x, int y, int rx, int ry, Uin
 				drawhorzlineclip(dst, color, x-k, y-h-1, x+k-1);
 				oh=h;
 			}
-			
+
 			ix = ix + iy / ry;
 			iy = iy - ix / ry;
-			
+
 		} while(i > h);
 	}
 }
@@ -1616,7 +1624,7 @@ static void draw_fillpoly(SDL_Surface *dst, int *vx, int *vy, int n, Uint32 colo
 	int ints;
 	int *polyints = PyMem_New(int, n);
 
-	
+
 	/* Determine Y maxima */
 	miny = vy[0];
 	maxy = vy[0];
@@ -1625,7 +1633,7 @@ static void draw_fillpoly(SDL_Surface *dst, int *vx, int *vy, int n, Uint32 colo
 		miny = min(miny, vy[i]);
 		maxy = max(maxy, vy[i]);
 	}
-	
+
 	/* Draw, scanning y */
 	for(y=miny; (y <= maxy); y++) {
 		ints = 0;
@@ -1657,7 +1665,7 @@ static void draw_fillpoly(SDL_Surface *dst, int *vx, int *vy, int n, Uint32 colo
 			}
 		}
 		qsort(polyints, ints, sizeof(int), compare_int);
-		
+
 		for (i=0; (i<ints); i+=2) {
 			drawhorzlineclip(dst, color, polyints[i], y, polyints[i+1]);
 		}
