@@ -29,6 +29,7 @@
 static int is_extended = 0;
 static int SaveTGA(SDL_Surface *surface, char *file, int rle);
 static int SaveTGA_RW(SDL_Surface *surface, SDL_RWops *out, int rle);
+static SDL_Surface* opengltosdl(void);
 
 
 #define DATAROW(data, row, width, height, flipped) \
@@ -108,13 +109,13 @@ static SDL_Surface* opengltosdl()
         PyObject *pyopengl, *readpixels = NULL;
         int typeflag=0, formatflag=0;
         SDL_Surface *surf;
-        Uint32 rmask, gmask, bmask, amask;
-        int i, depth, doalpha=0;
+        Uint32 rmask, gmask, bmask;
+        int i;
         unsigned char *pixels;
         PyObject *data;
 
         surf = SDL_GetVideoSurface();
-    
+
         pyopengl = PyImport_ImportModule("OpenGL.GL");
         if(pyopengl)
         {
@@ -139,7 +140,7 @@ static SDL_Surface* opengltosdl()
             return NULL;
         }
 
-        data = PyObject_CallFunction(readpixels, "iiiiii", 
+        data = PyObject_CallFunction(readpixels, "iiiiii",
                                 0, 0, surf->w, surf->h, formatflag, typeflag);
         if(!data)
         {
@@ -147,31 +148,17 @@ static SDL_Surface* opengltosdl()
                 return NULL;
         }
         pixels = (unsigned char*)PyString_AsString(data);
-        
+
         if(SDL_BYTEORDER == SDL_LIL_ENDIAN)
         {
-            if(doalpha)
-            {
-                rmask=0x000000FF; gmask=0x0000FF00; bmask=0x00FF00; amask=0xFF000000; depth=32;
-            }
-            else
-            {
-                rmask=0x000000FF; gmask=0x0000FF00; bmask=0x00FF00; amask=0x00000000; depth=24;
-            }
+            rmask=0x000000FF; gmask=0x0000FF00; bmask=0x00FF0000;
         }
         else
         {
-            if(doalpha)
-            {
-                rmask=0xFF000000; gmask=0x00FF0000; bmask=0x00FF00; amask=0x00000000; depth=32;
-            }
-            else
-            {
-                rmask=0x00FF0000; gmask=0x0000FF00; bmask=0x000000FF; amask=0x00000000; depth=24;
-            }
+            rmask=0x00FF0000; gmask=0x0000FF00; bmask=0x000000FF;
         }
-        surf = SDL_CreateRGBSurface(SDL_SWSURFACE, surf->w, surf->h, depth,
-                    rmask, gmask, bmask, amask);
+        surf = SDL_CreateRGBSurface(SDL_SWSURFACE, surf->w, surf->h, 24,
+                    rmask, gmask, bmask, 0);
         if(!surf)
         {
                 Py_DECREF(data);
@@ -181,7 +168,7 @@ static SDL_Surface* opengltosdl()
 
         for(i=0; i<surf->h; ++i)
                 memcpy(((char *) surf->pixels) + surf->pitch * i, pixels + 3*surf->w * (surf->h-i-1), surf->w*3);
-        
+
         Py_DECREF(data);
         return surf;
 }
@@ -207,7 +194,7 @@ PyObject* image_save(PyObject* self, PyObject* arg)
 	SDL_Surface *surf;
 	SDL_Surface *temp = NULL;
 	int result;
-	
+
 	if(!PyArg_ParseTuple(arg, "O!O", &PySurface_Type, &surfobj, &file))
 		return NULL;
 	surf = PySurface_AsSurface(surfobj);
@@ -289,6 +276,7 @@ PyObject* image_get_extended(PyObject* self, PyObject* arg)
     /*DOC*/    "string data you need. It can be one of the following, \"P\"\n"
     /*DOC*/    "for 8bit palette indices. \"RGB\" for 24bit RGB data, \"RGBA\"\n"
     /*DOC*/    "for 32bit RGB and alpha, or \"RGBX\" for 32bit padded RGB colors.\n"
+    /*DOC*/    "\"ARGB\" is a popular format for big endian platforms.\n"
     /*DOC*/    "\n"
     /*DOC*/    "These flags are a subset of the formats supported the PIL\n"
     /*DOC*/    "Python Image Library. Note that the \"P\" format only will\n"
@@ -317,7 +305,7 @@ PyObject* image_tostring(PyObject* self, PyObject* arg)
                 if(!surf)
                     return NULL;
 	}
-        
+
 	Rmask = surf->format->Rmask; Gmask = surf->format->Gmask;
 	Bmask = surf->format->Bmask; Amask = surf->format->Amask;
 	Rshift = surf->format->Rshift; Gshift = surf->format->Gshift;
@@ -453,7 +441,7 @@ PyObject* image_tostring(PyObject* self, PyObject* arg)
 					data[0] = (char)(((color & Rmask) >> Rshift) << Rloss);
 					data[1] = (char)(((color & Gmask) >> Gshift) << Gloss);
 					data[2] = (char)(((color & Bmask) >> Bshift) << Bloss);
-					data[3] = hascolorkey ? (char)(color!=colorkey)*255 : 
+					data[3] = hascolorkey ? (char)(color!=colorkey)*255 :
 								(char)(Amask ? (((color & Amask) >> Ashift) << Aloss) : 255);
 					data += 4;
 				}
@@ -496,6 +484,86 @@ PyObject* image_tostring(PyObject* self, PyObject* arg)
 		}
 		PySurface_Unlock(surfobj);
 	}
+	else if(!strcmp(format, "ARGB"))
+	{
+		hascolorkey = 0;
+
+		string = PyString_FromStringAndSize(NULL, surf->w*surf->h*4);
+		if(!string)
+			return NULL;
+		PyString_AsStringAndSize(string, &data, &len);
+
+		PySurface_Lock(surfobj);
+		pixels = (char*)surf->pixels;
+		switch(surf->format->BytesPerPixel)
+		{
+		case 1:
+			for(h=0; h<surf->h; ++h)
+			{
+				Uint8* ptr = (Uint8*)DATAROW(surf->pixels, h, surf->pitch, surf->h, flipped);
+				for(w=0; w<surf->w; ++w)
+				{
+					color = *ptr++;
+					data[1] = (char)surf->format->palette->colors[color].r;
+					data[2] = (char)surf->format->palette->colors[color].g;
+					data[3] = (char)surf->format->palette->colors[color].b;
+					data[0] = hascolorkey ? (char)(color!=colorkey)*255 : (char)255;
+					data += 4;
+				}
+			}break;
+		case 2:
+			for(h=0; h<surf->h; ++h)
+			{
+				Uint16* ptr = (Uint16*)DATAROW(surf->pixels, h, surf->pitch, surf->h, flipped);
+				for(w=0; w<surf->w; ++w)
+				{
+					color = *ptr++;
+					data[1] = (char)(((color & Rmask) >> Rshift) << Rloss);
+					data[2] = (char)(((color & Gmask) >> Gshift) << Gloss);
+					data[3] = (char)(((color & Bmask) >> Bshift) << Bloss);
+					data[0] = hascolorkey ? (char)(color!=colorkey)*255 :
+								(char)(Amask ? (((color & Amask) >> Ashift) << Aloss) : 255);
+					data += 4;
+				}
+			}break;
+		case 3:
+			for(h=0; h<surf->h; ++h)
+			{
+				Uint8* ptr = (Uint8*)DATAROW(surf->pixels, h, surf->pitch, surf->h, flipped);
+				for(w=0; w<surf->w; ++w)
+				{
+#if SDL_BYTEORDER == SDL_LIL_ENDIAN
+					color = ptr[0] + (ptr[1]<<8) + (ptr[2]<<16);
+#else
+					color = ptr[2] + (ptr[1]<<8) + (ptr[0]<<16);
+#endif
+					ptr += 3;
+					data[1] = (char)(((color & Rmask) >> Rshift) << Rloss);
+					data[2] = (char)(((color & Gmask) >> Gshift) << Gloss);
+					data[3] = (char)(((color & Bmask) >> Bshift) << Bloss);
+					data[0] = hascolorkey ? (char)(color!=colorkey)*255 :
+								(char)(Amask ? (((color & Amask) >> Ashift) << Aloss) : 255);
+					data += 4;
+				}
+			}break;
+		case 4:
+			for(h=0; h<surf->h; ++h)
+			{
+				Uint32* ptr = (Uint32*)DATAROW(surf->pixels, h, surf->pitch, surf->h, flipped);
+				for(w=0; w<surf->w; ++w)
+				{
+					color = *ptr++;
+					data[1] = (char)(((color & Rmask) >> Rshift) << Rloss);
+					data[2] = (char)(((color & Gmask) >> Gshift) << Rloss);
+					data[3] = (char)(((color & Bmask) >> Bshift) << Rloss);
+					data[0] = hascolorkey ? (char)(color!=colorkey)*255 :
+								(char)(Amask ? (((color & Amask) >> Ashift) << Rloss) : 255);
+					data += 4;
+				}
+			}break;
+		}
+		PySurface_Unlock(surfobj);
+	}
 	else
         {
                 if(temp) SDL_FreeSurface(temp);
@@ -523,6 +591,7 @@ PyObject* image_tostring(PyObject* self, PyObject* arg)
     /*DOC*/    "string data you need. It can be one of the following, \"P\"\n"
     /*DOC*/    "for 8bit palette indices. \"RGB\" for 24bit RGB data, \"RGBA\"\n"
     /*DOC*/    "for 32bit RGB and alpha, or \"RGBX\" for 32bit padded RGB colors.\n"
+    /*DOC*/    "\"ARGB\" is a popular format for big endian platforms.\n"
     /*DOC*/    "\n"
     /*DOC*/    "These flags are a subset of the formats supported the PIL\n"
     /*DOC*/    "Python Image Library. Note that the \"P\" format only create\n"
@@ -591,6 +660,30 @@ PyObject* image_fromstring(PyObject* self, PyObject* arg)
                                         0xFF, 0xFF<<8, 0xFF<<16, (alphamult?0xFF<<24:0));
 #else
                                         0xFF<<24, 0xFF<<16, 0xFF<<8, (alphamult?0xFF:0));
+#endif
+		if(!surf)
+			return RAISE(PyExc_SDLError, SDL_GetError());
+		SDL_LockSurface(surf);
+		for(looph=0; looph<h; ++looph)
+		{
+			Uint32* pix = (Uint32*)DATAROW(surf->pixels, looph, surf->pitch, h, flipped);
+			for(loopw=0; loopw<w; ++loopw)
+			{
+                                *pix++ = *((Uint32*)data);
+                                data += 4;
+			}
+		}
+		SDL_UnlockSurface(surf);
+	}
+	else if(!strcmp(format, "ARGB"))
+	{
+                if(len != w*h*4)
+			return RAISE(PyExc_ValueError, "String length does not equal format and resolution size");
+		surf = SDL_CreateRGBSurface(SDL_SRCALPHA, w, h, 32,
+#if SDL_BYTEORDER == SDL_LIL_ENDIAN
+                                        0xFF<<24, 0xFF, 0xFF<<8, 0xFF<<16);
+#else
+                                        0xFF, 0xFF<<24, 0xFF<<16, 0xFF<<8);
 #endif
 		if(!surf)
 			return RAISE(PyExc_SDLError, SDL_GetError());
