@@ -38,7 +38,7 @@ static PyObject* rect_new(PyTypeObject *type, PyObject *args, PyObject *kwds);
 
 GAME_Rect* GameRect_FromObject(PyObject* obj, GAME_Rect* temp)
 {
-	short val;
+	int val;
 	int length;
 
 	if(PyRect_Check(obj))
@@ -47,10 +47,10 @@ GAME_Rect* GameRect_FromObject(PyObject* obj, GAME_Rect* temp)
 	{
 		if(length == 4)
 		{
-			if(!ShortFromObjIndex(obj, 0, &val)) return NULL; temp->x = val;
-			if(!ShortFromObjIndex(obj, 1, &val)) return NULL; temp->y = val;
-			if(!ShortFromObjIndex(obj, 2, &val)) return NULL; temp->w = val;
-			if(!ShortFromObjIndex(obj, 3, &val)) return NULL; temp->h = val;
+			if(!IntFromObjIndex(obj, 0, &val)) return NULL; temp->x = val;
+			if(!IntFromObjIndex(obj, 1, &val)) return NULL; temp->y = val;
+			if(!IntFromObjIndex(obj, 2, &val)) return NULL; temp->w = val;
+			if(!IntFromObjIndex(obj, 3, &val)) return NULL; temp->h = val;
 			return temp;
 		}
 		if(length == 2)
@@ -58,14 +58,14 @@ GAME_Rect* GameRect_FromObject(PyObject* obj, GAME_Rect* temp)
 			PyObject* sub = PySequence_GetItem(obj, 0);
 			if(!sub || !PySequence_Check(sub) || PySequence_Length(sub)!=2)
 				{Py_XDECREF(sub); return NULL;}
-			if(!ShortFromObjIndex(sub, 0, &val)) {Py_DECREF(sub); return NULL;} temp->x = val;
-			if(!ShortFromObjIndex(sub, 1, &val)) {Py_DECREF(sub); return NULL;} temp->y = val;
+			if(!IntFromObjIndex(sub, 0, &val)) {Py_DECREF(sub); return NULL;} temp->x = val;
+			if(!IntFromObjIndex(sub, 1, &val)) {Py_DECREF(sub); return NULL;} temp->y = val;
 			Py_DECREF(sub);
 			sub = PySequence_GetItem(obj, 1);
 			if(!sub || !PySequence_Check(sub) || PySequence_Length(sub)!=2)
 				{Py_XDECREF(sub); return NULL;}
-			if(!ShortFromObjIndex(sub, 0, &val)) {Py_DECREF(sub); return NULL;} temp->w = val;
-			if(!ShortFromObjIndex(sub, 1, &val)) {Py_DECREF(sub); return NULL;} temp->h = val;
+			if(!IntFromObjIndex(sub, 0, &val)) {Py_DECREF(sub); return NULL;} temp->w = val;
+			if(!IntFromObjIndex(sub, 1, &val)) {Py_DECREF(sub); return NULL;} temp->h = val;
 			Py_DECREF(sub);
 			return temp;
 		}
@@ -96,45 +96,45 @@ GAME_Rect* GameRect_FromObject(PyObject* obj, GAME_Rect* temp)
 	return NULL;
 }
 
-static int Rect_SetTop(GAME_Rect* r, short val)
+static int Rect_SetTop(GAME_Rect* r, int val)
 {
 	r->y = val;
 	return 0;
-}	
-static int Rect_SetBottom(GAME_Rect* r, short val)
+}
+static int Rect_SetBottom(GAME_Rect* r, int val)
 {
 	r->y = val - r->h;
 	return 0;
-}	
-static int Rect_SetLeft(GAME_Rect* r, short val)
+}
+static int Rect_SetLeft(GAME_Rect* r, int val)
 {
 	r->x = val;
 	return 0;
-}	
-static int Rect_SetRight(GAME_Rect* r, short val)
+}
+static int Rect_SetRight(GAME_Rect* r, int val)
 {
 	r->x = val - r->w;
 	return 0;
 }
-static int Rect_SetWidth(GAME_Rect* r, short val)
+static int Rect_SetWidth(GAME_Rect* r, int val)
 {
 //	r->x -= val - r->w;
 	r->w = val;
 	return 0;
 }
-static int Rect_SetHeight(GAME_Rect* r, short val)
+static int Rect_SetHeight(GAME_Rect* r, int val)
 {
 //	r->y -= val - r->h;
 	r->h = val;
 	return 0;
 }
 
-PyObject* PyRect_New(GAME_Rect* r)
+PyObject* PyRect_New(SDL_Rect* r)
 {
 	PyRectObject* rect = PyObject_NEW(PyRectObject, &PyRect_Type);
 	if(!rect)
 		return NULL;
-	
+
 	rect->r.x = r->x;
 	rect->r.y = r->y;
 	rect->r.w = r->w;
@@ -143,17 +143,16 @@ PyObject* PyRect_New(GAME_Rect* r)
 	return (PyObject*)rect;
 }
 
-PyObject* PyRect_New4(short x, short y, short w, short h)
+PyObject* PyRect_New4(int x, int y, int w, int h)
 {
 	PyRectObject* rect = PyObject_NEW(PyRectObject, &PyRect_Type);
 	if(!rect)
 		return NULL;
-	
+
 	rect->r.x = x;
 	rect->r.y = y;
 	rect->r.w = w;
 	rect->r.h = h;
-
 	return (PyObject*)rect;
 }
 
@@ -183,12 +182,12 @@ static PyObject* rect_normalize(PyObject* oself, PyObject* args)
 	if(!PyArg_ParseTuple(args, ""))
 		return NULL;
 
-	if((short)self->r.w < 0)
+	if(self->r.w < 0)
 	{
 		self->r.x += self->r.w;
 		self->r.w = -self->r.w;
 	}
-	if((short)self->r.h < 0)
+	if(self->r.h < 0)
 	{
 		self->r.y += self->r.h;
 		self->r.h = -self->r.h;
@@ -209,12 +208,12 @@ static PyObject* rect_normalize(PyObject* oself, PyObject* args)
 static PyObject* rect_move(PyObject* oself, PyObject* args)
 {
 	PyRectObject* self = (PyRectObject*)oself;
-	short x, y;
+	int x, y;
 
-	if(!TwoShortsFromObj(args, &x, &y))
+	if(!TwoIntsFromObj(args, &x, &y))
 		return RAISE(PyExc_TypeError, "argument must contain two numbers");
 
-	return PyRect_New4((short)(self->r.x+x), (short)(self->r.y+y), self->r.w, self->r.h);
+	return PyRect_New4(self->r.x+x, self->r.y+y, self->r.w, self->r.h);
 }
 
     /*DOC*/ static char doc_move_ip[] =
@@ -227,9 +226,9 @@ static PyObject* rect_move(PyObject* oself, PyObject* args)
 static PyObject* rect_move_ip(PyObject* oself, PyObject* args)
 {
 	PyRectObject* self = (PyRectObject*)oself;
-	short x, y;
+	int x, y;
 
-	if(!TwoShortsFromObj(args, &x, &y))
+	if(!TwoIntsFromObj(args, &x, &y))
 		return RAISE(PyExc_TypeError, "argument must contain two numbers");
 
 	self->r.x += x;
@@ -252,12 +251,12 @@ static PyObject* rect_move_ip(PyObject* oself, PyObject* args)
 static PyObject* rect_inflate(PyObject* oself, PyObject* args)
 {
 	PyRectObject* self = (PyRectObject*)oself;
-	short x, y;
+	int x, y;
 
-	if(!TwoShortsFromObj(args, &x, &y))
+	if(!TwoIntsFromObj(args, &x, &y))
 		return RAISE(PyExc_TypeError, "argument must contain two numbers");
 
-	return PyRect_New4((short)(self->r.x-x/2), (short)(self->r.y-y/2), (short)(self->r.w+x), (short)(self->r.h+y));
+	return PyRect_New4(self->r.x-x/2, self->r.y-y/2, self->r.w+x, self->r.h+y);
 }
 
 
@@ -273,9 +272,9 @@ static PyObject* rect_inflate(PyObject* oself, PyObject* args)
 static PyObject* rect_inflate_ip(PyObject* oself, PyObject* args)
 {
 	PyRectObject* self = (PyRectObject*)oself;
-	short x, y;
+	int x, y;
 
-	if(!TwoShortsFromObj(args, &x, &y))
+	if(!TwoIntsFromObj(args, &x, &y))
 		return RAISE(PyExc_TypeError, "argument must contain two numbers");
 
 	self->r.x -= x/2;
@@ -300,10 +299,10 @@ static PyObject* rect_union(PyObject* oself, PyObject* args)
 {
 	PyRectObject* self = (PyRectObject*)oself;
 	GAME_Rect *argrect, temp;
-	short x, y, w, h;
+	int x, y, w, h;
 	if(!(argrect = GameRect_FromObject(args, &temp)))
 		return RAISE(PyExc_TypeError, "Argument must be rect style object");
-	
+
 	x = min(self->r.x, argrect->x);
 	y = min(self->r.y, argrect->y);
 	w = max(self->r.x+self->r.w, argrect->x+argrect->w) - x;
@@ -327,10 +326,10 @@ static PyObject* rect_union_ip(PyObject* oself, PyObject* args)
 {
 	PyRectObject* self = (PyRectObject*)oself;
 	GAME_Rect *argrect, temp;
-	short x, y, w, h;
+	int x, y, w, h;
 	if(!(argrect = GameRect_FromObject(args, &temp)))
 		return RAISE(PyExc_TypeError, "Argument must be rect style object");
-	
+
 	x = min(self->r.x, argrect->x);
 	y = min(self->r.y, argrect->y);
 	w = max(self->r.x+self->r.w, argrect->x+argrect->w) - x;
@@ -371,7 +370,7 @@ static PyObject* rect_unionall(PyObject* oself, PyObject* args)
 	b = self->r.y + self->r.h;
 	size = PySequence_Length(list); /*warning, size could be -1 on error?*/
 	if(size < 1)
-		return PyRect_New4((short)l, (short)t, (short)(r-l), (short)(b-t));
+		return PyRect_New4(l, t, r-l, b-t);
 
 	for(loop = 0; loop < size; ++loop)
 	{
@@ -388,7 +387,7 @@ static PyObject* rect_unionall(PyObject* oself, PyObject* args)
 		b = max(b, argrect->y+argrect->h);
 		Py_DECREF(obj);
 	}
-	return PyRect_New4((short)l, (short)t, (short)(r-l), (short)(b-t));
+	return PyRect_New4(l, t, r-l, b-t);
 }
 
 
@@ -421,7 +420,7 @@ static PyObject* rect_unionall_ip(PyObject* oself, PyObject* args)
 
 	size = PySequence_Length(list); /*warning, size could be -1 on error?*/
 	if(size < 1)
-		return PyRect_New4((short)l, (short)t, (short)(r-l), (short)(b-t));
+		return PyRect_New4(l, t, r-l, b-t);
 
 	for(loop = 0; loop < size; ++loop)
 	{
@@ -459,13 +458,13 @@ static PyObject* rect_unionall_ip(PyObject* oself, PyObject* args)
 static PyObject* rect_collidepoint(PyObject* oself, PyObject* args)
 {
 	PyRectObject* self = (PyRectObject*)oself;
-	short x, y;
+	int x, y;
 	int inside;
 
-	if(!TwoShortsFromObj(args, &x, &y))
+	if(!TwoIntsFromObj(args, &x, &y))
 		return RAISE(PyExc_TypeError, "argument must contain two numbers");
 
-	inside = x>=self->r.x && x<self->r.x+self->r.w && 
+	inside = x>=self->r.x && x<self->r.x+self->r.w &&
 				y>=self->r.y && y<self->r.y+self->r.h;
 
 	return PyInt_FromLong(inside);
@@ -523,7 +522,7 @@ static PyObject* rect_collidelist(PyObject* oself, PyObject* args)
 	{
 		obj = PySequence_GetItem(list, loop);
 		if(!obj || !(argrect = GameRect_FromObject(obj, &temp)))
-		{	
+		{
 			RAISE(PyExc_TypeError, "Argument must be a sequence of rectstyle objects.");
 			Py_XDECREF(obj);
 			break;
@@ -539,7 +538,7 @@ static PyObject* rect_collidelist(PyObject* oself, PyObject* args)
 	if(loop == size)
 		ret = PyInt_FromLong(-1);
 
-	return ret;	
+	return ret;
 }
 
 
@@ -578,7 +577,7 @@ static PyObject* rect_collidelistall(PyObject* oself, PyObject* args)
 		obj = PySequence_GetItem(list, loop);
 
 		if(!obj || !(argrect = GameRect_FromObject(obj, &temp)))
-		{	
+		{
 			Py_XDECREF(obj);
 			Py_DECREF(ret);
 			return RAISE(PyExc_TypeError, "Argument must be a sequence of rectstyle objects.");
@@ -598,7 +597,7 @@ static PyObject* rect_collidelistall(PyObject* oself, PyObject* args)
 		Py_DECREF(obj);
 	}
 
-	return ret;	
+	return ret;
 }
 
 
@@ -634,7 +633,7 @@ static PyObject* rect_collidedict(PyObject* oself, PyObject* args)
         while(PyDict_Next(dict, &loop, &key, &val))
 	{
 		if(!(argrect = GameRect_FromObject(key, &temp)))
-		{	
+		{
 			RAISE(PyExc_TypeError, "Argument must be a dict with rectstyle keys.");
 			break;
 		}
@@ -650,7 +649,7 @@ static PyObject* rect_collidedict(PyObject* oself, PyObject* args)
             Py_INCREF(Py_None);
             ret = Py_None;
         }
-	return ret;	
+	return ret;
 }
 
 
@@ -689,7 +688,7 @@ static PyObject* rect_collidedictall(PyObject* oself, PyObject* args)
         while(PyDict_Next(dict, &loop, &key, &val))
 	{
 		if(!(argrect = GameRect_FromObject(key, &temp)))
-		{	
+		{
 			Py_DECREF(ret);
 			return RAISE(PyExc_TypeError, "Argument must be a dict with rectstyle keys.");
 		}
@@ -704,7 +703,7 @@ static PyObject* rect_collidedictall(PyObject* oself, PyObject* args)
 		}
 	}
 
-	return ret;	
+	return ret;
 }
 
 
@@ -722,7 +721,7 @@ static PyObject* rect_collidedictall(PyObject* oself, PyObject* args)
 static PyObject* rect_clip(PyObject* self, PyObject* args)
 {
 	GAME_Rect *A, *B, temp;
-	short x, y, w, h;
+	int x, y, w, h;
 
 	A = &((PyRectObject*)self)->r;
 	if(!(B = GameRect_FromObject(args, &temp)))
@@ -742,7 +741,7 @@ static PyObject* rect_clip(PyObject* self, PyObject* args)
 		w = (B->x+B->w) - x;
 	else
 		goto nointersect;
-	
+
 	/* Top */
 	if((A->y >= B->y) && (A->y < (B->y+B->h)))
 		y = A->y;
@@ -810,7 +809,7 @@ static PyObject* rect_clamp(PyObject* oself, PyObject* args)
 {
 	PyRectObject* self = (PyRectObject*)oself;
 	GAME_Rect *argrect, temp;
-	short x, y;
+	int x, y;
 	if(!(argrect = GameRect_FromObject(args, &temp)))
 		return RAISE(PyExc_TypeError, "Argument must be rect style object");
 
@@ -850,7 +849,7 @@ static PyObject* rect_clamp_ip(PyObject* oself, PyObject* args)
 {
 	PyRectObject* self = (PyRectObject*)oself;
 	GAME_Rect *argrect, temp;
-	short x, y;
+	int x, y;
 	if(!(argrect = GameRect_FromObject(args, &temp)))
 		return RAISE(PyExc_TypeError, "Argument must be rect style object");
 
@@ -896,12 +895,12 @@ static struct PyMethodDef rect_methods[] =
 	{"clamp_ip",			 (PyCFunction)rect_clamp_ip,		  1,	    doc_clamp_ip},
 
 	{"move",			(PyCFunction)rect_move, 		1, doc_move},
-	{"inflate",			(PyCFunction)rect_inflate,		1, doc_inflate},		
+	{"inflate",			(PyCFunction)rect_inflate,		1, doc_inflate},
 	{"union",			(PyCFunction)rect_union,		1, doc_union},
 	{"unionall",		(PyCFunction)rect_unionall,		1, doc_unionall},
 
 	{"move_ip",			(PyCFunction)rect_move_ip,		1, doc_move_ip},
-	{"inflate_ip",		(PyCFunction)rect_inflate_ip,	1, doc_inflate_ip},		
+	{"inflate_ip",		(PyCFunction)rect_inflate_ip,	1, doc_inflate_ip},
 	{"union_ip",		(PyCFunction)rect_union_ip,		1, doc_union_ip},
 	{"unionall_ip", 	(PyCFunction)rect_unionall_ip,	1, doc_unionall_ip},
 
@@ -915,9 +914,9 @@ static struct PyMethodDef rect_methods[] =
 /* these are totally unwritten. volunteers? */
 /*	{"cleanup",			(PyCFunction)rect_cleanup,		1, doc_cleanup}, */
 /*	{"remove",			(PyCFunction)rect_remove,		1, doc_remove}, */
-        
+
         {"__reduce__",          (PyCFunction)rect_reduce, 0, NULL},
-        
+
 	{NULL,		NULL}
 };
 
@@ -933,7 +932,7 @@ static int rect_length(PyRectObject *self)
 
 static PyObject* rect_item(PyRectObject *self, int i)
 {
-	short* data = (short*)&self->r;
+	int* data = (int*)&self->r;
 	if(i<0 || i>3)
 		return RAISE(PyExc_IndexError, "Invalid rect Index");
 
@@ -942,19 +941,19 @@ static PyObject* rect_item(PyRectObject *self, int i)
 
 static int rect_ass_item(PyRectObject *self, int i, PyObject *v)
 {
-	short val;
-	short* data = (short*)&self->r;
+	int val;
+	int* data = (int*)&self->r;
 	if(i<0 || i>3)
 	{
 		RAISE(PyExc_IndexError, "Invalid rect Index");
 		return -1;
 	}
-	if(!ShortFromObj(v, &val))
+	if(!IntFromObj(v, &val))
 	{
 		RAISE(PyExc_TypeError, "Must assign numeric values");
 		return -1;
 	}
-	data[i] = (short)val;
+	data[i] = val;
 	return 0;
 }
 
@@ -962,9 +961,9 @@ static int rect_ass_item(PyRectObject *self, int i, PyObject *v)
 static PyObject* rect_slice(PyRectObject *self, int ilow, int ihigh)
 {
 	PyObject *list;
-	short* data = (short*)&self->r;
+	int* data = (int*)&self->r;
 	int numitems, loop, l = 4;
-	
+
 	if (ihigh < 0) ihigh += l;
 	if (ilow  < 0) ilow  += l;
 	if (ilow < 0) ilow = 0;
@@ -985,10 +984,10 @@ static PyObject* rect_slice(PyRectObject *self, int ilow, int ihigh)
 
 static int rect_ass_slice(PyRectObject *self, int ilow, int ihigh, PyObject *v)
 {
-	short* data = (short*)&self->r;
+	int* data = (int*)&self->r;
 	int numitems, loop, l = 4;
-	short val;
-	
+	int val;
+
 	if(!PySequence_Check(v))
 	{
 		RAISE(PyExc_TypeError, "Assigned slice must be a sequence");
@@ -1012,7 +1011,7 @@ static int rect_ass_slice(PyRectObject *self, int ilow, int ihigh, PyObject *v)
 
 	for(loop = 0; loop < numitems; ++loop)
 	{
-		if(!ShortFromObjIndex(v, loop, &val)) return -1;
+		if(!IntFromObjIndex(v, loop, &val)) return -1;
 		data[loop+ilow] = val;
 	}
 
@@ -1050,7 +1049,7 @@ static int rect_coerce(PyObject** o1, PyObject** o2)
 		Py_INCREF(new1);
 	}
 	else if((r = GameRect_FromObject(*o1, &temp)))
-		new1 = PyRect_New(r);
+		new1 = PyRect_New4(r->x, r->y, r->w, r->h);
 	else
 		return 1;
 
@@ -1060,7 +1059,7 @@ static int rect_coerce(PyObject** o1, PyObject** o2)
 		Py_INCREF(new2);
 	}
 	else if((r = GameRect_FromObject(*o2, &temp)))
-		new2 = PyRect_New(r);
+		new2 = PyRect_New4(r->x, r->y, r->w, r->h);
 	else
 	{
 		Py_DECREF(new1);
@@ -1081,7 +1080,7 @@ static PyNumberMethods rect_as_number = {
 	(binaryfunc)NULL,		/*divmod*/
 	(ternaryfunc)NULL,		/*power*/
 	(unaryfunc)NULL,		/*negative*/
-	(unaryfunc)NULL,		/*pos*/ 
+	(unaryfunc)NULL,		/*pos*/
 	(unaryfunc)NULL,		/*abs*/
 	(inquiry)rect_nonzero,	/*nonzero*/
 	(unaryfunc)NULL,		/*invert*/
@@ -1108,8 +1107,8 @@ static void rect_dealloc(PyRectObject *self)
 
 static PyObject *rect_repr(PyRectObject *self)
 {
-	char string[256];	
-	sprintf(string, "<rect(%d, %d, %d, %d)>", self->r.x, self->r.y, self->r.w, self->r.h);	
+	char string[256];
+	sprintf(string, "<rect(%d, %d, %d, %d)>", self->r.x, self->r.y, self->r.w, self->r.h);
 	return PyString_FromString(string);
 }
 
@@ -1148,7 +1147,7 @@ static PyObject *rect_getattr(PyRectObject *self, char *name)
 {
 	PyObject *ret = NULL;
 	GAME_Rect *r = &self->r;
-	
+
 	if(!strcmp(name, "top") || !strcmp(name, "y"))
 		ret = PyInt_FromLong(r->y);
 	else if(!strcmp(name, "bottom"))
@@ -1190,7 +1189,7 @@ static PyObject *rect_getattr(PyRectObject *self, char *name)
 
 	else if(!strcmp(name, "__safe_for_unpickling__"))
                 ret = PyInt_FromLong(1);
-	else 
+	else
 		ret = Py_FindMethod(rect_methods, (PyObject *)self, name);
 
 	return ret;
@@ -1199,82 +1198,82 @@ static PyObject *rect_getattr(PyRectObject *self, char *name)
 static int rect_setattr(PyRectObject *self, char *name, PyObject *op)
 {
 	int ret = -1;
-	short val1, val2;
+	int val1, val2;
 	GAME_Rect *r = &self->r;
-	
+
 	if(!strcmp(name, "top") || !strcmp(name, "y"))
 	{
-		if(ShortFromObj(op, &val1))
+		if(IntFromObj(op, &val1))
 			ret = Rect_SetTop(r, val1);
-	}	
+	}
 	else if(!strcmp(name, "bottom"))
 	{
-		if(ShortFromObj(op, &val1))
+		if(IntFromObj(op, &val1))
 			ret = Rect_SetBottom(r, val1);
-	}	
+	}
 	else if(!strcmp(name, "left") || !strcmp(name, "x"))
 	{
-		if(ShortFromObj(op, &val1))
+		if(IntFromObj(op, &val1))
 			ret = Rect_SetLeft(r, val1);
-	}	
+	}
 	else if(!strcmp(name, "right"))
 	{
-		if(ShortFromObj(op, &val1))
+		if(IntFromObj(op, &val1))
 			ret = Rect_SetRight(r, val1);
-	}	
+	}
 	else if(!strcmp(name, "width") || !strcmp(name, "w"))
 	{
-		if(ShortFromObj(op, &val1))
+		if(IntFromObj(op, &val1))
 			ret = Rect_SetWidth(r, val1);
-	}	
+	}
 	else if(!strcmp(name, "height") || !strcmp(name, "h"))
 	{
-		if(ShortFromObj(op, &val1))
+		if(IntFromObj(op, &val1))
 			ret = Rect_SetHeight(r, val1);
-	}	
+	}
 	else if(!strcmp(name, "topleft"))
 	{
-		if(TwoShortsFromObj(op, &val1, &val2))
+		if(TwoIntsFromObj(op, &val1, &val2))
 		{
 			Rect_SetLeft(r, val1);
 			ret = Rect_SetTop(r, val2);
 		}
-	}	
+	}
 	else if(!strcmp(name, "bottomleft"))
 	{
-		if(TwoShortsFromObj(op, &val1, &val2))
+		if(TwoIntsFromObj(op, &val1, &val2))
 		{
 			Rect_SetLeft(r, val1);
 			ret = Rect_SetBottom(r, val2);
 		}
-	}	
+	}
 	else if(!strcmp(name, "topright"))
 	{
-		if(TwoShortsFromObj(op, &val1, &val2))
+		if(TwoIntsFromObj(op, &val1, &val2))
 		{
 			Rect_SetRight(r, val1);
 			ret = Rect_SetTop(r, val2);
 		}
-	}	
+	}
 	else if(!strcmp(name, "bottomright"))
 	{
-		if(TwoShortsFromObj(op, &val1, &val2))
+		if(TwoIntsFromObj(op, &val1, &val2))
 		{
 			Rect_SetRight(r, val1);
 			ret = Rect_SetBottom(r, val2);
 		}
-	}	
+	}
 	else if(!strcmp(name, "size"))
 	{
-		if(TwoShortsFromObj(op, &val1, &val2))
+		if(TwoIntsFromObj(op, &val1, &val2))
 		{
 			Rect_SetWidth(r, val1);
 			ret = Rect_SetHeight(r, val2);
 		}
-	}	
+	}
 	else if(!strcmp(name, "center"))
 	{
-		if(TwoShortsFromObj(op, &val1, &val2))
+		if(TwoIntsFromObj(op, &val1, &val2))
 		{
 			r->x += val1 - (r->x + r->w / 2);
 			r->y += val2 - (r->y + r->h / 2);
@@ -1283,7 +1282,7 @@ static int rect_setattr(PyRectObject *self, char *name, PyObject *op)
 	}
 	else if(!strcmp(name, "centerx"))
 	{
-		if(ShortFromObj(op, &val1))
+		if(IntFromObj(op, &val1))
 		{
 			r->x += val1 - (r->x + r->w / 2);
 			ret = 0;
@@ -1291,7 +1290,7 @@ static int rect_setattr(PyRectObject *self, char *name, PyObject *op)
 	}
 	else if(!strcmp(name, "centery"))
 	{
-		if(ShortFromObj(op, &val1))
+		if(IntFromObj(op, &val1))
 		{
 			r->y += val1 - (r->y + r->h / 2);
 			ret = 0;
@@ -1300,7 +1299,7 @@ static int rect_setattr(PyRectObject *self, char *name, PyObject *op)
 
 	else if(!strcmp(name, "midleft"))
 	{
-		if(TwoShortsFromObj(op, &val1, &val2))
+		if(TwoIntsFromObj(op, &val1, &val2))
 		{
 			r->x = val1;
 			r->y += val2 - (r->y + r->h / 2);
@@ -1309,7 +1308,7 @@ static int rect_setattr(PyRectObject *self, char *name, PyObject *op)
 	}
 	else if(!strcmp(name, "midright"))
 	{
-		if(TwoShortsFromObj(op, &val1, &val2))
+		if(TwoIntsFromObj(op, &val1, &val2))
 		{
 			r->x = val1 - r->w;
 			r->y += val2 - (r->y + r->h / 2);
@@ -1318,7 +1317,7 @@ static int rect_setattr(PyRectObject *self, char *name, PyObject *op)
 	}
 	else if(!strcmp(name, "midtop"))
 	{
-		if(TwoShortsFromObj(op, &val1, &val2))
+		if(TwoIntsFromObj(op, &val1, &val2))
 		{
 			r->x += val1 - (r->x + r->w / 2);
 			r->y = val2;
@@ -1327,15 +1326,15 @@ static int rect_setattr(PyRectObject *self, char *name, PyObject *op)
 	}
 	else if(!strcmp(name, "midbottom"))
 	{
-		if(TwoShortsFromObj(op, &val1, &val2))
+		if(TwoIntsFromObj(op, &val1, &val2))
 		{
 			r->x += val1 - (r->x + r->w / 2);
 			r->y = val2 - r->h;
 			ret = 0;
 		}
 	}
-	
-	else	
+
+	else
 	{
 		RAISE(PyExc_AttributeError, "Attribute cannot be modified");
 		return -1;
@@ -1351,34 +1350,57 @@ static int rect_setattr(PyRectObject *self, char *name, PyObject *op)
     /*DOC*/ static char doc_Rect_MODULE[] =
     /*DOC*/    "The rectangle object is a useful object\n"
     /*DOC*/    "representing a rectangle area. Rectangles are\n"
-	/*DOC*/    "created from the pygame.Rect() function. This routine\n"
-	/*DOC*/    "is also in the locals module, so importing the locals\n"
-	/*DOC*/    "into your namespace allows you to just use Rect().\n"
+    /*DOC*/    "created from the pygame.Rect() function. This routine\n"
+    /*DOC*/    "is also in the locals module, so importing the locals\n"
+    /*DOC*/    "into your namespace allows you to just use Rect().\n"
     /*DOC*/    "\n"
     /*DOC*/    "Rect contains helpful methods, as well as a list of\n"
     /*DOC*/    "modifiable members:\n"
-    /*DOC*/    "top, bottom, left, right, topleft, topright,\n"
-    /*DOC*/    "bottomleft, bottomright, size, width, height,\n"
-    /*DOC*/    "center, centerx, centery, midleft, midright, midtop,\n"
-	/*DOC*/    "midbottom. When changing thesemembers, the rectangle\n"
+#if 1
+  /*NODOC*/    "top, bottom, left, right, topleft, topright,\n"
+  /*NODOC*/    "bottomleft, bottomright, size, width, height,\n"
+  /*NODOC*/    "center, centerx, centery, midleft, midright, midtop,\n"
+  /*NODOC*/    "midbottom.\n"
+#else
+    /*DOC*/    "<table border="0" cellspacing=0 cellpadding=0 width=66%><tr valign=top><td align=left><ul><li>top<li>bottom<li>left<li>right</ul></td>\n"
+    /*DOC*/    "<td align=left><ul><li>topleft<li>topright<li>bottomleft<li>bottomright</ul></td>\n"
+    /*DOC*/    "<td align=left><ul><li>midleft<li>midright<li>midtop<li>midbottom</ul></td>\n"
+    /*DOC*/    "<td align=left><ul><li>center<li>centerx<li>centery</ul></td>\n"
+    /*DOC*/    "<td align=left><ul><li>size<li>width<li>height</ul></td>\n"
+    /*DOC*/    "</tr></table><br>\n"
+#endif
+    /*DOC*/    "When changing these members, the rectangle\n"
     /*DOC*/    "will be moved to the given assignment. (except when\n"
     /*DOC*/    "changing the size, width, or height member, which will\n"
     /*DOC*/    "resize the rectangle from the topleft corner)\n"
     /*DOC*/    "\n"
     /*DOC*/    "The rectstyle arguments used frequently with the\n"
     /*DOC*/    "Rect object (and elsewhere in pygame) is one of\n"
-    /*DOC*/    "the following things. First, an actual Rect\n"
-    /*DOC*/    "object. Second, a sequence of [xpos, ypos, width,\n"
-    /*DOC*/    "height]. Lastly, a pair of sequences, representing\n"
-    /*DOC*/    "the position and size [[xpos, ypos], [width,\n"
-    /*DOC*/    "height]]. Also, if a method takes a rectstyle\n"
-    /*DOC*/    "argument as its only argument, you can simply pass\n"
-    /*DOC*/    "four arguments representing xpos, ypos, width,\n"
-    /*DOC*/    "height. A rectstyle argument can also be _any_ python\n"
-    /*DOC*/    "object with an attribute named 'rect'.\n"
+    /*DOC*/    "the following things.\n"
+#if 1
+  /*NODOC*/    "First, an actual Rect\n"
+  /*NODOC*/    "object. Second, a sequence of [xpos, ypos, width,\n"
+  /*NODOC*/    "height]. Lastly, a pair of sequences, representing\n"
+  /*NODOC*/    "the position and size [[xpos, ypos], [width,\n"
+  /*NODOC*/    "height]]. Also, if a method takes a rectstyle\n"
+  /*NODOC*/    "argument as its only argument, you can simply pass\n"
+  /*NODOC*/    "four arguments representing xpos, ypos, width,\n"
+  /*NODOC*/    "height. A rectstyle argument can also be _any_ python\n"
+  /*NODOC*/    "object with an attribute named 'rect'.\n"
+#else
+    /*DOC*/    "<table border=0 cellspacing=0 cellpadding=0 width=80%>\n"
+    /*DOC*/    "<tr align=left valign=top><td align=left valign=middle width=20%><blockquote> </blockquote></td><td align=left valign=top><ul>\n"
+    /*DOC*/    "<li>an actual Rect object. \n"
+    /*DOC*/    "<li>a sequence of [xpos, ypos, width, height]. \n"
+    /*DOC*/    "<li>a pair of sequences, representing the position and size [[xpos, ypos], [width,height]]. \n"
+    /*DOC*/    "<li>if a method takes a rectstyle argument <b>as its <i>only</i> argument</b>, you can simply pass four arguments representing xpos, ypos, width, height. \n"
+    /*DOC*/    "</ul>and perhaps most importantly:\n"
+    /*DOC*/    "<ul><li>A rectstyle argument can also be <b><strong>_any_ python object</b> with an attribute named <b>'rect'.</b></strong>\n"
+    /*DOC*/    "</ul></td></tr></table>\n"
+#endif
     /*DOC*/ ;
 
-static PyTypeObject PyRect_Type = { 
+static PyTypeObject PyRect_Type = {
 	PyObject_HEAD_INIT(0)
 	0,							/*size*/
 	"Rect", 					/*name*/
@@ -1473,7 +1495,7 @@ static PyObject* rect_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 static PyMethodDef rect__builtins__[] =
 {
 #if PYTHON_API_VERSION < 1011 /*PYTHON2.2*/
-	{ "Rect", RectInit, 1, doc_Rect }, 
+	{ "Rect", RectInit, 1, doc_Rect },
 #endif
 	{NULL, NULL}
 };
@@ -1489,7 +1511,7 @@ void initrect(void)
 {
 	PyObject *module, *dict, *apiobj;
 	static void* c_api[PYGAMEAPI_RECT_NUMSLOTS];
-	
+
 	/* Create the module and add the functions */
 	PyType_Init(PyRect_Type);
 
