@@ -48,6 +48,8 @@ static PyObject* surface_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     /*DOC*/    "\n"
     /*DOC*/    "Returns the RGB color values at a given pixel. If the\n"
     /*DOC*/    "Surface has no per-pixel alpha, the alpha will be 255 (opaque).\n"
+    /*DOC*/    "A pixel outside the surface area will raise an IndexError.\n"
+    /*DOC*/    "\n"
     /*DOC*/    "\n"
     /*DOC*/    "This function will need to temporarily lock the surface.\n"
     /*DOC*/ ;
@@ -110,7 +112,8 @@ static PyObject* surf_get_at(PyObject* self, PyObject* arg)
     /*DOC*/    "set pixel at given position\n"
     /*DOC*/    "\n"
     /*DOC*/    "Assigns color to the image at the give position. Color can be a\n"
-    /*DOC*/    "RGBA sequence or a mapped color integer.\n"
+    /*DOC*/    "RGBA sequence or a mapped color integer. Setting the pixel outside\n"
+    /*DOC*/    "the clip area or surface area will have no effect.\n"
     /*DOC*/    "\n"
     /*DOC*/    "In some situations just using the fill() function with a one-pixel\n"
     /*DOC*/    "sized rectangle will be quicker. Also the fill function does not\n"
@@ -136,15 +139,16 @@ static PyObject* surf_set_at(PyObject* self, PyObject* args)
 	if(surf->flags & SDL_OPENGL)
 		return RAISE(PyExc_SDLError, "Cannot call on OPENGL Surfaces");
 
-	if(x < 0 || x >= surf->w || y < 0 || y >= surf->h)
-	{
-		PyErr_SetString(PyExc_IndexError, "pixel coordinate out of range");
-		return NULL;
-	}
-
 	if(format->BytesPerPixel < 1 || format->BytesPerPixel > 4)
 		return RAISE(PyExc_RuntimeError, "invalid color depth for surface");
 
+	if(x < surf->clip_rect.x || x >= surf->clip_rect.x + surf->clip_rect.w ||
+                    y < surf->clip_rect.y || y >= surf->clip_rect.y + surf->clip_rect.h)
+	{
+		/*out of clip area*/
+                RETURN_NONE
+	}
+
 	if(PyInt_Check(rgba_obj))
 		color = (Uint32)PyInt_AsLong(rgba_obj);
 	else if(RGBAFromObj(rgba_obj, rgba))
@@ -425,7 +429,7 @@ static PyObject* surf_set_palette(PyObject* self, PyObject* args)
 	SDL_Color* colors;
 	PyObject* list, *item;
 	int i, len;
-	short r, g, b;
+	int r, g, b;
 
 	if(!PyArg_ParseTuple(args, "O", &list))
 		return NULL;
@@ -454,7 +458,7 @@ static PyObject* surf_set_palette(PyObject* self, PyObject* args)
 			free((char*)colors);
 			return RAISE(PyExc_TypeError, "takes a sequence of sequence of RGB");
 		}
-		if(!ShortFromObjIndex(item, 0, &r) || !ShortFromObjIndex(item, 1, &g) || !ShortFromObjIndex(item, 2, &b))
+		if(!IntFromObjIndex(item, 0, &r) || !IntFromObjIndex(item, 1, &g) || !IntFromObjIndex(item, 2, &b))
 			return RAISE(PyExc_TypeError, "RGB sequence must contain numeric values");
 
 		colors[i].r = (unsigned char)r;
@@ -735,10 +739,10 @@ static PyObject* surf_convert(PyObject* self, PyObject* args)
 		}
 		else
 		{
-			short bpp;
+			int bpp;
 			SDL_PixelFormat format;
 			memcpy(&format, surf->format, sizeof(format));
-			if(ShortFromObj(argobject, &bpp))
+			if(IntFromObj(argobject, &bpp))
 			{
 				int Rmask, Gmask, Bmask, Amask;
 				if(flags!=-1 && flags&SDL_SRCALPHA)
@@ -885,6 +889,7 @@ static PyObject* surf_set_clip(PyObject* self, PyObject* args)
 	SDL_Surface* surf = PySurface_AsSurface(self);
 	PyObject* item;
 	GAME_Rect *rect=NULL, temp;
+        SDL_Rect sdlrect;
 	int result;
 
 	if(PyTuple_Size(args))
@@ -896,9 +901,15 @@ static PyObject* surf_set_clip(PyObject* self, PyObject* args)
 		    if(!rect)
 			    return RAISE(PyExc_ValueError, "invalid rectstyle object");
 		}
+                sdlrect.x = rect->x;
+                sdlrect.y = rect->y;
+                sdlrect.h = rect->h;
+                sdlrect.w = rect->w;
+                result = SDL_SetClipRect(surf, &sdlrect);
 	}
+        else
+                result = SDL_SetClipRect(surf, NULL);
 
-	result = SDL_SetClipRect(surf, (SDL_Rect*)rect);
 	if(result == -1)
 		return RAISE(PyExc_SDLError, SDL_GetError());
 
@@ -919,7 +930,7 @@ static PyObject* surf_set_clip(PyObject* self, PyObject* args)
 static PyObject* surf_get_clip(PyObject* self, PyObject* args)
 {
 	SDL_Surface* surf = PySurface_AsSurface(self);
-	return PyRect_New((GAME_Rect*)&surf->clip_rect);
+	return PyRect_New(&surf->clip_rect);
 }
 
 
@@ -947,6 +958,7 @@ static PyObject* surf_fill(PyObject* self, PyObject* args)
 	int result;
 	PyObject* rgba_obj;
 	Uint8 rgba[4];
+        SDL_Rect sdlrect;
 
 	if(!PyArg_ParseTuple(args, "O|O", &rgba_obj, &r))
 		return NULL;
@@ -964,7 +976,7 @@ static PyObject* surf_fill(PyObject* self, PyObject* args)
 	if(!r)
 	{
 		rect = &temp;
-		temp.x = temp.y = (short)0;
+		temp.x = temp.y = 0;
 		temp.w = surf->w;
 		temp.h = surf->h;
 	}
@@ -978,13 +990,18 @@ static PyObject* surf_fill(PyObject* self, PyObject* args)
 		rect = &temp;
 	}
 
+        sdlrect.x = rect->x;
+        sdlrect.y = rect->y;
+        sdlrect.w = rect->w;
+        sdlrect.h = rect->h;
+
 	PySurface_Prep(self);
-	result = SDL_FillRect(surf, (SDL_Rect*)rect, color);
+	result = SDL_FillRect(surf, &sdlrect, color);
 	PySurface_Unprep(self);
 
 	if(result == -1)
 		return RAISE(PyExc_SDLError, SDL_GetError());
-	return PyRect_New(rect);
+	return PyRect_New(&sdlrect);
 }
 
 
@@ -1115,8 +1132,8 @@ static PyObject* surf_blit(PyObject* self, PyObject* args)
 	GAME_Rect* src_rect, temp;
 	PyObject* srcobject, *argpos, *argrect = NULL;
 	int dx, dy, result;
-	SDL_Rect dest_rect;
-	short sx, sy;
+	SDL_Rect dest_rect, sdlsrc_rect;
+	int sx, sy;
 
 	if(!PyArg_ParseTuple(args, "O!O|O", &PySurface_Type, &srcobject, &argpos, &argrect))
 		return NULL;
@@ -1130,10 +1147,10 @@ static PyObject* surf_blit(PyObject* self, PyObject* args)
 		dx = src_rect->x;
 		dy = src_rect->y;
 	}
-	else if(TwoShortsFromObj(argpos, &sx, &sy))
+	else if(TwoIntsFromObj(argpos, &sx, &sy))
 	{
-		dx = (int)sx;
-		dy = (int)sy;
+		dx = sx;
+		dy = sy;
 	}
 	else
 		return RAISE(PyExc_TypeError, "invalid destination position for blit");
@@ -1155,12 +1172,16 @@ static PyObject* surf_blit(PyObject* self, PyObject* args)
 	dest_rect.y = (short)dy;
 	dest_rect.w = (unsigned short)src_rect->w;
 	dest_rect.h = (unsigned short)src_rect->h;
+        sdlsrc_rect.x = (short)src_rect->x;
+        sdlsrc_rect.y = (short)src_rect->y;
+        sdlsrc_rect.w = (unsigned short)src_rect->w;
+        sdlsrc_rect.h = (unsigned short)src_rect->h;
 
-	result = PySurface_Blit(self, srcobject, &dest_rect, (SDL_Rect*)src_rect);
+	result = PySurface_Blit(self, srcobject, &dest_rect, &sdlsrc_rect);
 	if(result != 0)
 	    return NULL;
 
-	return PyRect_New((GAME_Rect*)&dest_rect);
+	return PyRect_New(&dest_rect);
 }
 
 
@@ -1254,7 +1275,7 @@ static PyObject* surf_get_height(PyObject* self, PyObject* args)
 static PyObject* surf_get_rect(PyObject* self, PyObject* args)
 {
 	SDL_Surface* surf = PySurface_AsSurface(self);
-	return PyRect_New4(0, 0, (short)surf->w, (short)surf->h);
+	return PyRect_New4(0, 0, surf->w, surf->h);
 }
 
 
@@ -1763,7 +1784,7 @@ static PyObject* Surface(PyObject* self, PyObject* arg)
 	Uint32 flags = 0;
 	int width, height;
 	PyObject *depth=NULL, *masks=NULL, *final;
-	short bpp;
+	int bpp;
 	Uint32 Rmask, Gmask, Bmask, Amask;
 	SDL_Surface* surface;
 	SDL_PixelFormat default_format;
@@ -1774,7 +1795,7 @@ static PyObject* Surface(PyObject* self, PyObject* arg)
 	{
 		if(PySurface_Check(depth))
 			return RAISE(PyExc_ValueError, "cannot pass surface for depth and color masks");
-		if(!ShortFromObj(depth, &bpp))
+		if(!IntFromObj(depth, &bpp))
 			return RAISE(PyExc_ValueError, "invalid bits per pixel depth argument");
 		if(!PySequence_Check(masks) || PySequence_Length(masks)!=4)
 			return RAISE(PyExc_ValueError, "masks argument must be sequence of four numbers");
@@ -1784,7 +1805,7 @@ static PyObject* Surface(PyObject* self, PyObject* arg)
 	}
 	else if(depth && PyNumber_Check(depth))/*use default masks*/
 	{
-		if(!ShortFromObj(depth, &bpp))
+		if(!IntFromObj(depth, &bpp))
 			return RAISE(PyExc_ValueError, "invalid bits per pixel depth argument");
 		if(flags & SDL_SRCALPHA)
 		{
